@@ -1,5 +1,5 @@
-use super::Decode;
 use crate::io::Buf;
+use crate::postgres::database::Postgres;
 use byteorder::NetworkEndian;
 
 #[derive(Debug)]
@@ -11,8 +11,8 @@ pub struct BackendKeyData {
     pub secret_key: u32,
 }
 
-impl Decode for BackendKeyData {
-    fn decode(mut buf: &[u8]) -> crate::Result<Self> {
+impl BackendKeyData {
+    pub(crate) fn read(mut buf: &[u8]) -> crate::Result<Self> {
         let process_id = buf.get_u32::<NetworkEndian>()?;
         let secret_key = buf.get_u32::<NetworkEndian>()?;
 
@@ -25,13 +25,13 @@ impl Decode for BackendKeyData {
 
 #[cfg(test)]
 mod tests {
-    use super::{BackendKeyData, Decode};
+    use super::BackendKeyData;
 
     const BACKEND_KEY_DATA: &[u8] = b"\0\0'\xc6\x89R\xc5+";
 
     #[test]
     fn it_decodes_backend_key_data() {
-        let message = BackendKeyData::decode(BACKEND_KEY_DATA).unwrap();
+        let message = BackendKeyData::read(BACKEND_KEY_DATA).unwrap();
 
         assert_eq!(message.process_id, 10182);
         assert_eq!(message.secret_key, 2303903019);
