@@ -1,5 +1,6 @@
 use crate::io::Buf;
-use crate::postgres::protocol::{Decode, TypeId};
+use crate::postgres::database::Postgres;
+use crate::postgres::protocol::TypeId;
 use byteorder::NetworkEndian;
 
 #[derive(Debug)]
@@ -7,8 +8,8 @@ pub struct ParameterDescription {
     pub ids: Box<[TypeId]>,
 }
 
-impl Decode for ParameterDescription {
-    fn decode(mut buf: &[u8]) -> crate::Result<Self> {
+impl ParameterDescription {
+    pub(crate) fn read(mut buf: &[u8]) -> crate::Result<Self> {
         let cnt = buf.get_u16::<NetworkEndian>()? as usize;
         let mut ids = Vec::with_capacity(cnt);
 
@@ -24,12 +25,12 @@ impl Decode for ParameterDescription {
 
 #[cfg(test)]
 mod test {
-    use super::{Decode, ParameterDescription};
+    use super::ParameterDescription;
 
     #[test]
-    fn it_decodes_parameter_description() {
+    fn it_reads_parameter_description() {
         let buf = b"\x00\x02\x00\x00\x00\x00\x00\x00\x05\x00";
-        let desc = ParameterDescription::decode(buf).unwrap();
+        let desc = ParameterDescription::read(buf).unwrap();
 
         assert_eq!(desc.ids.len(), 2);
         assert_eq!(desc.ids[0].0, 0x0000_0000);
@@ -37,9 +38,9 @@ mod test {
     }
 
     #[test]
-    fn it_decodes_empty_parameter_description() {
+    fn it_reads_empty_parameter_description() {
         let buf = b"\x00\x00";
-        let desc = ParameterDescription::decode(buf).unwrap();
+        let desc = ParameterDescription::read(buf).unwrap();
 
         assert_eq!(desc.ids.len(), 0);
     }
