@@ -1,9 +1,10 @@
 use crate::io::Buf;
-use crate::postgres::protocol::Decode;
 use std::str::{self, FromStr};
 
-#[derive(Debug, Copy, Clone)]
-pub enum Severity {
+use crate::postgres::database::Postgres;
+
+#[derive(Debug, Copy, Clone, PartialEq, Eq)]
+pub(crate) enum Severity {
     Panic,
     Fatal,
     Error,
@@ -15,7 +16,7 @@ pub enum Severity {
 }
 
 impl Severity {
-    pub fn is_error(self) -> bool {
+    pub(crate) fn is_error(self) -> bool {
         match self {
             Severity::Panic | Severity::Fatal | Severity::Error => true,
             _ => false,
@@ -45,28 +46,28 @@ impl FromStr for Severity {
 }
 
 #[derive(Debug)]
-pub struct Response {
-    pub severity: Severity,
-    pub code: Box<str>,
-    pub message: Box<str>,
-    pub detail: Option<Box<str>>,
-    pub hint: Option<Box<str>>,
-    pub position: Option<usize>,
-    pub internal_position: Option<usize>,
-    pub internal_query: Option<Box<str>>,
-    pub where_: Option<Box<str>>,
-    pub schema: Option<Box<str>>,
-    pub table: Option<Box<str>>,
-    pub column: Option<Box<str>>,
-    pub data_type: Option<Box<str>>,
-    pub constraint: Option<Box<str>>,
-    pub file: Option<Box<str>>,
-    pub line: Option<usize>,
-    pub routine: Option<Box<str>>,
+pub(crate) struct Response {
+    pub(crate) severity: Severity,
+    pub(crate) code: Box<str>,
+    pub(crate) message: Box<str>,
+    pub(crate) detail: Option<Box<str>>,
+    pub(crate) hint: Option<Box<str>>,
+    pub(crate) position: Option<usize>,
+    pub(crate) internal_position: Option<usize>,
+    pub(crate) internal_query: Option<Box<str>>,
+    pub(crate) where_: Option<Box<str>>,
+    pub(crate) schema: Option<Box<str>>,
+    pub(crate) table: Option<Box<str>>,
+    pub(crate) column: Option<Box<str>>,
+    pub(crate) data_type: Option<Box<str>>,
+    pub(crate) constraint: Option<Box<str>>,
+    pub(crate) file: Option<Box<str>>,
+    pub(crate) line: Option<usize>,
+    pub(crate) routine: Option<Box<str>>,
 }
 
-impl Decode for Response {
-    fn decode(mut buf: &[u8]) -> crate::Result<Self> {
+impl Response {
+    pub(crate) fn read(mut buf: &[u8]) -> crate::Result<Self> {
         let mut code = None::<Box<str>>;
         let mut message = None::<Box<str>>;
         let mut severity = None::<Box<str>>;
@@ -140,7 +141,7 @@ impl Decode for Response {
                     internal_query = Some(field_value.into());
                 }
 
-                b'w' => {
+                b'W' => {
                     where_ = Some(field_value.into());
                 }
 
@@ -226,7 +227,7 @@ impl Decode for Response {
 
 #[cfg(test)]
 mod tests {
-    use super::{Decode, Response, Severity};
+    use super::{Response, Severity};
     use matches::assert_matches;
 
     const RESPONSE: &[u8] = b"SNOTICE\0VNOTICE\0C42710\0Mextension \"uuid-ossp\" already exists, \
@@ -234,7 +235,7 @@ mod tests {
 
     #[test]
     fn it_decodes_response() {
-        let message = Response::decode(RESPONSE).unwrap();
+        let message = Response::read(RESPONSE).unwrap();
 
         assert_matches!(message.severity, Severity::Notice);
         assert_eq!(&*message.code, "42710");
