@@ -1,10 +1,11 @@
 use std::borrow::Cow;
 use std::convert::{TryFrom, TryInto};
 
+#[derive(Debug)]
 pub struct Url(url::Url);
 
 impl TryFrom<String> for Url {
-    type Error = crate::Error;
+    type Error = url::ParseError;
 
     fn try_from(value: String) -> Result<Self, Self::Error> {
         (&value).try_into()
@@ -12,7 +13,7 @@ impl TryFrom<String> for Url {
 }
 
 impl<'s> TryFrom<&'s str> for Url {
-    type Error = crate::Error;
+    type Error = url::ParseError;
 
     fn try_from(value: &'s str) -> Result<Self, Self::Error> {
         Ok(Url(value.parse()?))
@@ -20,7 +21,7 @@ impl<'s> TryFrom<&'s str> for Url {
 }
 
 impl<'s> TryFrom<&'s String> for Url {
-    type Error = crate::Error;
+    type Error = url::ParseError;
 
     fn try_from(value: &'s String) -> Result<Self, Self::Error> {
         (value.as_str()).try_into()
@@ -28,6 +29,11 @@ impl<'s> TryFrom<&'s String> for Url {
 }
 
 impl Url {
+    #[allow(dead_code)]
+    pub(crate) fn as_str(&self) -> &str {
+        self.0.as_str()
+    }
+
     pub fn host(&self) -> &str {
         let host = self.0.host_str();
 
@@ -78,7 +84,7 @@ impl Url {
         }
     }
 
-    pub fn get_param(&self, key: &str) -> Option<Cow<str>> {
+    pub fn param(&self, key: &str) -> Option<Cow<str>> {
         self.0
             .query_pairs()
             .find_map(|(key_, val)| if key == key_ { Some(val) } else { None })
